from googletrans import Translator
from bhasha_codes import bhasha_kosh
from gtts import gTTS

class ShabdDhwani:
    bhasha_codes = dict(map(reversed, bhasha_kosh.items()))
    def shabd_se_dhwani(shabd,bhasha,filename):
        """ shabd = text,
            bhasaa = language(mainly allowed in code)
                = file
            filename=app//audio.mp3
            anuvadak = Translator
            anuvadit = Translated
        """
        # translates the text into german language
        anuvadak = Translator().translate(shabd,dest=bhasha)
        anuvadit_file=gTTS(text=anuvadak.text,lang=bhasha)    
        anuvadit_file.save(filename)

    def shabd_ki_bhasha_badlo(shabd,bhasha):
        return Translator().translate(shabd, dest=bhasha).text

    def bhasa_badlkr_kya_bole(shabd,bhasha):
        return Translator().translate(shabd, dest=bhasha).pronunciation

    def shabd_ki_bhasha_jaano(shabd):
        return bhasha_kosh[Translator().detect(shabd).lang]

    def shabd_ki_bhasha_jaano_code(shabd):
        return Translator().detect(shabd).lang



from PIL import Image
from pytesseract import image_to_string,image_to_pdf_or_hocr

"""
Type of:
photo_ka_naam: string
pdf_ka_naam: string

"""
class PhotoShabd:
    def photo_ka_text(photo_ka_naam):
        return image_to_string(Image.open(photo_ka_naam))

    def photo_ki_pdf(photo_ka_naam,pdf_ka_naam):
        pdf = image_to_pdf_or_hocr(photo_ka_naam, extension='pdf')
        with open(pdf_ka_naam,'w+b') as f:
            f.write(pdf)




from .photo_se_text import PhotoShabd
from .text_bol_uthega import ShabdDhwani



class PhotoAwaj:
      
    def photo_se_awaj(photo_ka_naam,bhasha,awaj_ka_naam):
        return ShabdDhwani.shabd_se_dhwani(PhotoShabd.photo_ka_text(photo_ka_naam),bhasha,awaj_ka_naam)

    def photo_se_bhasha_badlo(photo_ka_naam,bhasha):
        return ShabdDhwani.shabd_ki_bhasha_badlo(photo_ka_text(photo_ka_naam),bhasha)

    def photo_m_kaun_sii_bhasha(photo_ka_naam):
        return ShabdDhwani.shabd_ki_bhasha_jaano(photo_ka_text(photo_ka_naam))

#PhotoAwaj.photo_se_awaj('test.png','hi','fg.mp3')



from distutils.core import setup
setup(
  name = 'freshlybuiltimagebol',         
  packages = ['freshlybuiltimagebol'],   
  version = '0.0.1',     
  license='MIT',        
  description = 'Image Bhi Bol Uthegi',   
  author = 'Vishal Sharma',                   
  author_email = 'vishalsharma.gbpecdelhi@gmail.com',      
  url = 'https://github.com/FreshlyBuilt/freshlybuiltimagebol',   
  download_url = 'https://github.com/FreshlyBuilt/freshlybuiltimagebol/archive/v0.0.1.tar.gz',  
  keywords = ['Image', 'Audio', 'Text'],   
  install_requires=[            
          'hyper',
          'googletrans',
          'gTTS',
          'Pillow',
          'pytesseract'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
